from zs_utils.api.wildberries.base_api import WildberriesAPI


class GetWildberriesOrders(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1orders/get
    """

    http_method = "GET"
    resource_method = "api/v2/orders"
    required_params = [
        "date_start",
        "take",
        "skip",
    ]
    allowed_params = [
        "date_end",
        "status",
        "id",
    ]


class GetWildberriesSupplies(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies/get
    """

    http_method = "GET"
    resource_method = "api/v2/supplies"
    required_params = [
        "status",
    ]


class GetWildberriesSupplyOrders(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies~1%7Bid%7D~1orders/get
    """

    http_method = "GET"
    resource_method = "api/v2/supplies/{supply_id}/orders"
    required_params = [
        "supply_id",
    ]


class GetWildberriesSupplyBarcode(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies~1%7Bid%7D~1barcode/get
    """

    http_method = "GET"
    resource_method = "api/v2/supplies/{supply_id}/barcode"
    required_params = [
        "supply_id",
        "type",
    ]


class GetWildberriesOrdersSVGStickers(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1orders~1stickers/post
    """

    http_method = "POST"
    resource_method = "api/v2/orders/stickers"
    required_params = [
        "orderIds",
    ]


class GetWildberriesOrdersPDFStickers(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1orders~1stickers~1pdf/post
    """

    http_method = "POST"
    resource_method = "api/v2/orders/stickers/pdf"
    required_params = [
        "orderIds",
    ]


class CreateWildberriesSupply(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies/post
    """

    http_method = "POST"
    resource_method = "api/v2/supplies"


class AddOrdersToWildberriesSupply(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies~1%7Bid%7D/put
    """

    http_method = "PUT"
    resource_method = "api/v2/supplies/{supply_id}"
    required_params = [
        "supply_id",
        "orders",
    ]


class CloseWildberriesSupply(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1supplies~1%7Bid%7D~1close/post
    """

    http_method = "POST"
    resource_method = "api/v2/supplies/{supply_id}/close"
    required_params = [
        "supply_id",
    ]


class UpdateWildberriesOrdersStatus(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1orders/put
    """

    http_method = "PUT"
    resource_method = "api/v2/orders"
    required_params = [
        "orderId",
        "status",
    ]
    allowed_params = [
        "sgtin",
    ]



from zs_utils.api.wildberries.base_api import WildberriesAPI


class GetWildberriesWarehouseList(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1warehouses/get
    """

    http_method = "GET"
    resource_method = "api/v2/warehouses"



from celery import current_app as app
from zs_utils.email.services import EmailService


@app.task()
def send_email_task(
    emails: list[str],
    subject: str,
    title: str,
    email_icon_path: str,
    body_content: str,
    **kwargs,
):
    return EmailService.send_standard_team_email(
        receivers=emails,
        subject=subject,
        title=title,
        email_icon_path=email_icon_path,
        body_content=body_content,
    )



from setuptools import setup, find_packages


setup(
    name="zonesmart-utils",
    version="0.3.2",
    author="Zonesmart",
    author_email="kamil@zonesmart.ru",
    packages=find_packages(include=["zs_utils", "zs_utils.*"]),
)



from zs_utils.api.wildberries.base_api import WildberriesAPI


class GetWildberriesNomenclatureList(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Prosmotr/paths/~1content~1v1~1cards~1cursor~1list/post
    """

    http_method = "POST"
    resource_method = "content/v1/cards/cursor/list"
    required_params = ["sort"]


class GetWildberriesNomenclatureByVendorCode(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Prosmotr/paths/~1content~1v1~1cards~1filter/post
    """

    http_method = "POST"
    resource_method = "content/v1/cards/filter"
    required_params = ["vendorCodes"]


class GetWildberriesPrices(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Ceny/paths/~1public~1api~1v1~1info/get
    """

    http_method = "GET"
    resource_method = "public/api/v1/info"
    allowed_params = ["quantity"]


class UpdateWildberriesPrices(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Ceny/paths/~1public~1api~1v1~1prices/post
    """

    http_method = "POST"
    resource_method = "public/api/v1/prices"
    array_payload = True


class UpdateWildberriesDiscounts(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Promokody-i-skidki/paths/~1public~1api~1v1~1updateDiscounts/post
    """

    http_method = "POST"
    resource_method = "public/api/v1/updateDiscounts"
    array_payload = True


class RevokeWildberriesDiscounts(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Promokody-i-skidki/paths/~1public~1api~1v1~1revokeDiscounts/post
    """

    http_method = "POST"
    resource_method = "public/api/v1/revokeDiscounts"
    array_payload = True


class GetWildberrriesListingStocks(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1stocks/get
    """

    http_method = "GET"
    resource_method = "api/v2/stocks"
    required_params = ["skip", "take"]
    allowed_params = ["search"]


class DeleteWildberrriesStocks(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1stocks/delete
    """

    http_method = "DELETE"
    resource_method = "api/v2/stocks"
    array_payload = True


class UpdateWildberrriesStocks(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Marketplace/paths/~1api~1v2~1stocks/post
    """

    http_method = "POST"
    resource_method = "api/v2/stocks"
    array_payload = True


class CreateWildberrriesBarcodes(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Prosmotr/paths/~1content~1v1~1barcodes/post
    """

    http_method = "POST"
    resource_method = "content/v1/barcodes"
    required_params = ["count"]


class GetWildberriesFailedToUploadNomenclatureList(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Prosmotr/paths/~1content~1v1~1cards~1error~1list/get
    """

    http_method = "GET"
    resource_method = "content/v1/cards/error/list"


class CreateWildberriesNomenclature(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Zagruzka/paths/~1content~1v1~1cards~1upload/post
    """

    http_method = "POST"
    resource_method = "content/v1/cards/upload"
    array_payload = True


class UpdateWildberriesNomenclature(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Zagruzka/paths/~1content~1v1~1cards~1update/post
    """

    http_method = "POST"
    resource_method = "content/v1/cards/update"
    array_payload = True


class AddWildberriesNomenclaturesToCard(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Zagruzka/paths/~1content~1v1~1cards~1upload~1add/post
    """

    http_method = "POST"
    resource_method = "content/v1/cards/add"
    required_params = [
        "vendorCode",
        "cards",
    ]


class UpdateWildberriesNomenclatureImages(WildberriesAPI):
    """
    https://openapi.wb.ru/#tag/Kontent-Mediafajly/paths/~1content~1v1~1media~1save/post
    """

    http_method = "POST"
    resource_method = "content/v1/media/save"
    required_params = [
        "vendorCode",
        "data",
    ]
